@@ -19,6 +19,9 @@ class phplistPlugin {
   function parseThankyou($pageid = 0,$userid = 0,$text = "") {
     return $text;
   }
+  # abstract method to be overriden
+  function displayUsers($user, $email, $listing){
+  }
 
   function adminmenu() {
     return array (
