@@ -1,3 +1,3 @@
 
 <p>Ta strona pokazuje dostpn odebran statystyk. Panuje tu jeszcze troche baagan i wymaga uaktualnienia w przyszych wersjach.</p>
-<p>Wyslij Twoje komentarze i sugestie do <a href="http://mantis.phplist.com">Mantis</a></p>
\ No newline at end of file
+<p>Wyslij Twoje komentarze i sugestie do <a href="http://mantis.tincan.co.uk">Mantis</a></p>
\ No newline at end of file
