@@ -1,3 +1,3 @@
 
 <p>Trang n&agrave;y hi&#7875;n th&#7883; nh&#7919;ng th&#7889;ng k&ecirc; c&oacute; th&#7875; l&#7845;y v&#7873;. Hi&#7879;n t&#7841;i trang n&agrave;y c&ograve;n nhi&#7873;u vi&#7879;c ph&#7843;i l&agrave;m v&agrave; c&#7847;n &#273;&#432;&#7907;c c&#7853;p nh&#7853;t trong c&aacute;c phi&ecirc;n b&#7843;n t&#7899;i.</p>
-<p>G&#7917;i nh&#7853;n x&eacute;t v&agrave; g&#7907;i &yacute; c&#7911;a b&#7841;n t&#7899;i <a href="http://mantis.phplist.com">Mantis</a></p>
+<p>G&#7917;i nh&#7853;n x&eacute;t v&agrave; g&#7907;i &yacute; c&#7911;a b&#7841;n t&#7899;i <a href="http://mantis.tincan.co.uk">Mantis</a></p>
