@@ -29,24 +29,28 @@ $GLOBALS['database_module'] = $database_module;
 $GLOBALS['show_dev_errors'] = $show_dev_errors;
 
 ## @@ would be nice to move this to the config file at some point
-$GLOBALS['scheme'] = 'http';
+# http://mantis.phplist.com/view.php?id=15521
+## set it on the fly, although that will probably only work with Apache
+$GLOBALS['scheme'] = (isset($_SERVER['HTTPS']) && (strtolower($_SERVER['HTTPS']) == 'on')) ? 'https' : 'http';
 
 ## spelling mistake in earlier version, make sure to set it correctly
 if (!isset($bounce_unsubscribe_threshold) && isset($bounce_unsubscribe_treshold)) {
   $bounce_unsubscribe_threshold = $bounce_unsubscribe_treshold;
 }
 
-function removeXss($string) {
-  if (is_array($string)) {
-    $return = array();
-    foreach ($string as $key => $val) {
-      $return[removeXss($key)] = removeXss($val);
+if (!function_exists('removexss')) {
+  function removeXss($string) {
+    if (is_array($string)) {
+      $return = array();
+      foreach ($string as $key => $val) {
+        $return[removeXss($key)] = removeXss($val);
+      }
+      return $return;
     }
-    return $return;
+    #$string = preg_replace('/<script/im','&lt;script',$string);
+    $string = htmlspecialchars($string);
+    return $string;
   }
-  #$string = preg_replace('/<script/im','&lt;script',$string);
-  $string = htmlspecialchars($string);
-  return $string;
 }
 
-?>
\ No newline at end of file
+?>
