@@ -3,7 +3,9 @@
 $lan = array(
 
 'The temporary directory for uploading (%s) is not writable, so import will fail' => 'The temporary directory for uploading (%s) is not writable, so import will fail',
+'Invalid Email' => 'Invalid Email',
 'Import cleared' => 'Import cleared',
+'Continue' => 'Continue',
 'Reset Import session' => 'Reset Import session',
 'File is either too large or does not exist.' => 'File is either too large or does not exist.',
 'No file was specified. Maybe the file is too big? ' => 'No file was specified. Maybe the file is too big? ',
@@ -21,31 +23,48 @@ $lan = array(
 'Create new one' => 'Create new one',
 'Skip Column' => 'Skip Column',
 'Import Attributes' => 'Import Attributes',
+'Continue' => 'Continue',
 'Please identify the target of the following unknown columns' => 'Please identify the target of the following unknown columns',
 'Summary' => 'Summary',
 'maps to' => 'maps to',
 'Create new Attribute' => 'Create new Attribute',
+'maps to' => 'maps to',
+'Skip Column' => 'Skip Column',
+'maps to' => 'maps to',
 '%d lines will be imported' => '%d lines will be imported',
 'Confirm Import' => 'Confirm Import',
 'Test Output' => 'Test Output',
+'Record has no email' => 'Record has no email',
+'Invalid Email' => 'Invalid Email',
 'clear value' => 'clear value',
 'New Attribute' => 'New Attribute',
 'Skip value' => 'Skip value',
 'duplicate' => 'duplicate',
 'Duplicate Email' => 'Duplicate Email',
 ' user imported as ' => ' user imported as ',
+'duplicate' => 'duplicate',
+'duplicate' => 'duplicate',
+'Duplicate Email' => 'Duplicate Email',
 'All the emails already exist in the database and are member of the lists' => 'All the emails already exist in the database and are member of the lists',
 '%s emails succesfully imported to the database and added to %d lists.' => '%s emails succesfully imported to the database and added to %d lists.',
 '%d emails subscribed to the lists' => '%d emails subscribed to the lists',
 '%s emails already existed in the database' => '%s emails already existed in the database',
 '%d Invalid Emails found.' => '%d Invalid Emails found.',
 'These records were added, but the email has been made up from ' => 'These records were added, but the email has been made up from ',
+'These records were deleted. Check your source and reimport the data. Duplicates will be identified.' => 'These records were deleted. Check your source and reimport the data. Duplicates will be identified.',
 'User data was updated for %d users' => 'User data was updated for %d users',
 '%d users were matched by foreign key, %d by email' => '%d users were matched by foreign key, %d by email',
+'phplist Import Results' => 'phplist Import Results',
 'Test output<br/>If the output looks ok, click %s to submit for real' => 'Test output<br/>If the output looks ok, click %s to submit for real',
+'Confirm Import' => 'Confirm Import',
+'Import some more emails' => 'Import some more emails',
+'Adding users to list' => 'Adding users to list',
+'Select the lists to add the emails to' => 'Select the lists to add the emails to',
+'No lists available' => 'No lists available',
+'Add a list' => 'Add a list',
 'Select the groups to add the users to' => 'Select the groups to add the users to',
 'automatically added' => 'automatically added',
-'importintro' => '<p class="information">The file you upload will need to have the attributes of the records on    the first line.
+ 'importintro' => '<p class="information">The file you upload will need to have the attributes of the records on    the first line.
     Make sure that the email column is called "email" and not something like "e-mail" or
     "Email Address".
     Case is not important.
@@ -72,17 +91,24 @@ The value [number] can be used to insert the sequence number for importing.',
 'retainold_blurb' => 'If you check "Retain Old User Email", a conflict of two emails being the same will keep the old one and add "duplicate" to the new one. If you don\'t check it, the old one will get "duplicate" and the new one will take precedence.',
 'sendnotification_blurb' => 'If you choose "send notification email" the users you are adding will be sent the request for confirmation of subscription to which they will have to reply. This is recommended, because it will identify invalid emails.',
 'phplist Import  Results' => 'phplist Import  Results',
+'File containing emails' => 'File containing emails',
+'Field Delimiter' => 'Field Delimiter',
 '(default is TAB)' => '(default is TAB)',
+'Record Delimiter' => 'Record Delimiter',
 '(default is line break)' => '(default is line break)',
+'Test output' => 'Test output',
 'Show Warnings' => 'Show Warnings',
 'Omit Invalid' => 'Omit Invalid',
 'Assign Invalid' => 'Assign Invalid',
+'Overwrite Existing' => 'Overwrite Existing',
 'Retain Old User Email' => 'Retain Old User Email',
 'Send&nbsp;Notification&nbsp;email' => 'Send&nbsp;Notification&nbsp;email',
+'Make confirmed immediately' => 'Make confirmed immediately',
 'Import' => 'Import',
+
+## added 2008-05-12
 'phplistuploadlimit' => '<br/>PHPlist will not process files larger than %dMB',
 'Cannot find column with email, please make sure the column is called &quot;email&quot; and not eg e-mail, and that your column delimiter is correct' => 'Cannot find column with email, please make sure the column is called &quot;email&quot; and not eg e-mail, and that your column delimiter is correct',
-'Use of wrong characters in filename, allowed are: ' => 'Use of wrong characters in filename, allowed are: ',
-'%d Duplicate Emails found.' => '%d Duplicate Emails found.',
+
 );
 ?>
\ No newline at end of file
