@@ -3,8 +3,8 @@ $lan = array(
   'SaveChanges' => 'Enregistrer les modifications',
   'NameNotEmpty' => 'Vous devez choisir un nom:',
   'NameNotUnique' => 'Ce nom est d&eacute;j&agrave; pris',
-  'ExistingAttr' => 'Attributs existants:<p>',
-  'NoAttrYet' => 'Aucun Attribut n&rsquo;a encore &eacute;t&eacute; d&eacute;fini<br>',
+  'ExistingAttr' => 'Attributs existants:',
+  'NoAttrYet' => 'Aucun Attribut n&rsquo;a encore &eacute;t&eacute; d&eacute;fini<br/>',
   'Attribute' => 'Attribut:',
   'Delete' => 'Supprimer',
   'Name' => 'Nom:',
