@@ -3,8 +3,8 @@ $lan = array(
 
   "loading" => "Carregando",
   "done" => "Conclu&iacute;do",
-  "name_empty" => "O campo Nome n&aacute; pode ficar em branco:",
-  "name_not_unique" => "S&oacute; o Nome n&atilde;o &eacute; suficiente",
+  "name_empty" => "O campo Nome n&atilde;o pode ficar em branco:",
+  "name_not_unique" => "Nome j&aacute; existe",
   "continue" => "Continuar",
   'add' => 'Adicionar',
 
