@@ -2,9 +2,8 @@
 
 $lan = array(
   'PHPList Users' => 'Usu&aacute;rios PHPList',
-  'on' => 'na', # as in Member of a list (user A on list B)
+  'on' => 'na',
   'List Membership' => 'Lista de Membros',
-  'No Lists' => 'Nenhuam Lista',
+  'No Lists' => 'Nenhuma Lista',
 );
-
 ?>
