@@ -49,7 +49,7 @@ $html = '';
 $result = Sql_query("SELECT * FROM $tables[list] $subselect order by listorder");
 while ($row = Sql_fetch_array($result)) {
   $count = Sql_Fetch_Row_Query("select count(*) from {$tables['listuser']} where listid = {$row["id"]} ");
-  $desc = stripslashes($row['description']);
+  $desc = htmlspecialchars(stripslashes($row['description']));
   if ($row['rssfeed']) {
     $feed = $row['rssfeed'];
     # reformat string, so it wraps if it's very long
