@@ -23,7 +23,7 @@ if (USETINYMCEMESG && file_exists(TINYMCEPATH)) {
   $useTinyMCE = 1;
 }
 
-include $GLOBALS["coderoot"] . "date.php";
+include_once dirname(__FILE__). "/date.php";
 
 $errormsg = '';
 $rss_content = '';
@@ -50,7 +50,7 @@ if (isset($_POST['send'])) {
 if (isset($_POST['prepare'])) {
   $prepare = $_POST["prepare"];
 } else {
-  $prepage = '';
+  $prepare = '';
 }
 if (isset($_GET['id'])) {
   $id = sprintf('%d',$_GET["id"]);  // Only get this from the GET variable
@@ -103,6 +103,11 @@ if ($id) {
     $done = 1;
     return;
   }
+  foreach (array('message', 'msgsubject') as $key) {
+    if (isset($_POST[$key])) {
+     $_POST[$key] = stripslashes($_POST[$key]);
+    }
+  }
   while ($msg = Sql_fetch_array($result)) {
     foreach ($DBstruct["message"] as $field => $rec) {
       if (!isset($_POST[$field])) {
@@ -123,10 +128,26 @@ if ($id) {
   // A bit of additional cleanup
   if (!isset($_POST["from"]))
     $_POST["from"] = $_POST["fromfield"];  // Database field name doesn't match form fieldname...
+
+  if (!isset($_POST["forwardsubject"])) {
+     $_POST["forwardsubject"] = "";
+  }
+  else $_POST["forwardsubject"] = sprintf("%s", $_POST["forwardsubject"]);
+
+  if (!isset($_POST["forwardmessage"])) {
+     $_POST["forwardmessage"] = "";
+  }
+  else $_POST["forwardmessage"] = sprintf("%s", $_POST["forwardmessage"]);
+
+  if (!isset($_POST["forwardfooter"])) {
+     $_POST["forwardfooter"] = "";
+  }
+  else $_POST["forwardfooter"] = sprintf("%s", $_POST["forwardfooter"]);
+
   if (!isset($_POST["msgsubject"])) {
-    $_POST["msgsubject"] = $_POST["subject"];
+    $_POST["msgsubject"] = sprintf("%s",$_POST["subject"]);
   } else {
-    $_POST['subject'] = $_POST['msgsubject'];
+    $_POST['subject'] = sprintf("%s",$_POST['msgsubject']);
   }
   if ((!isset($_POST["year"]) || !is_array($_POST["year"])) && $_POST["embargo"] && $_POST["embargo"] != "0000-00-00 00:00:00") {
      $embargo->setDateTime($_POST["embargo"]);
@@ -147,13 +168,19 @@ if ($id) {
 // If we've got magic quotes on, then we need to get rid of the slashes - either
 // from the database or from the previous $_POST
 #if (get_magic_quotes_gpc()) {
-  $_POST["msgsubject"] = stripslashes($_POST["msgsubject"]);
+//  $_POST["msgsubject"] = stripslashes($_POST["msgsubject"]);
+    #0013076: different content when forwarding 'to a friend'
+  $_POST["forwardsubject"] = stripslashes($_POST["forwardsubject"]);
   $_POST["from"] = stripslashes($_POST["from"]);
   $_POST["tofield"] = stripslashes($_POST["tofield"]);
   $_POST["replyto"] = stripslashes($_POST["replyto"]);
-  $_POST["message"] = stripslashes($_POST["message"]);
+//  $_POST["message"] = stripslashes($_POST["message"]);
+  #0013076: different content when forwarding 'to a friend'
+  $_POST["forwardmessage"] = stripslashes($_POST["forwardmessage"]);
   $_POST["textmessage"] = stripslashes($_POST["textmessage"]);
   $_POST["footer"] = stripslashes($_POST["footer"]);
+  #0013076: different content when forwarding 'to a friend'
+  $_POST["forwardfooter"] = stripslashes($_POST["forwardfooter"]);
 #}
 
 #input checking#######################
@@ -185,11 +212,31 @@ if (preg_match("/\n|\r/",$_POST["from"])) {
 } else {
   $from = $_POST["from"];
 }
+
 if (preg_match("/\n|\r/",$_POST["msgsubject"])) {
   $subject = "";
 } else {
   $subject = $_POST["msgsubject"];
 }
+
+if (preg_match("/\n|\r/",$_POST["forwardsubject"])) {
+  $forwardsubject = "";
+} else {
+  $forwardsubject = $_POST["forwardsubject"];
+}
+
+if (preg_match("/\n|\r/",$_POST["forwardmessage"])) {
+  $forwardmessage = "";
+} else {
+  $forwardmessage = $_POST["forwardmessage"];
+}
+
+if (preg_match("/\n|\r/",$_POST["forwardfooter"])) {
+  $forwardfooter = "";
+} else {
+  $forwardfooter = $_POST["forwardfooter"];
+}
+
 $message = $_POST["message"];
 
 // If the variable isn't filled in, then the input fields don't default to the
@@ -343,6 +390,14 @@ if ($send || $sendtest || $prepare || $save) {
     }
   }
 
+  #0013076: different content when forwarding 'to a friend'
+  if (FORWARD_ALTERNATIVE_CONTENT && $_GET['tab'] == 'Forward') {
+    foreach( array('forwardsubject', 'forwardmessage', 'forwardfooter') as $var) {
+      Sql_Query(sprintf('replace into %s (name,id,data) values("%s",%d,"%s")',
+        $tables["messagedata"], $var, $messageid, addslashes($_REQUEST[$var])));
+    }
+  }
+
 # we want to create a join on tables as follows, in order to find users who have their attributes to the values chosen
 # (independent of their list membership).
 # select
@@ -442,6 +497,7 @@ if ($send || $sendtest || $prepare || $save) {
     $operator = $_POST["criteria_operator"];
     if (is_array($_POST["criteria_values"])) {
       $values = join(", ",$_POST["criteria_values"]);
+      $values = cleanCommaList($values);
     } else {
       $values = $_POST["criteria_values"];
     }
@@ -483,7 +539,7 @@ if ($send || $sendtest || $prepare || $save) {
   }
 
 
-  if (ALLOW_ATTACHMENTS) {
+  if (ALLOW_ATTACHMENTS && isset($_FILES) && is_array($_FILES) && sizeof($_FILES) > 0) {
     for ($att_cnt = 1;$att_cnt <= NUMATTACHMENTS;$att_cnt++) {
       $fieldname = "attachment".$att_cnt;
       $tmpfile = $_FILES[$fieldname]['tmp_name'];
@@ -604,12 +660,19 @@ if ($send || $sendtest || $prepare || $save) {
       $address = trim($address);
       $result = Sql_query(sprintf('select id,email,uniqid,htmlemail,rssfrequency,confirmed from %s where email = "%s"',$tables["user"],$address));
       if ($user = Sql_fetch_array($result)) {
-        if (SEND_ONE_TESTMAIL) {
-          $success = sendEmail($id, $address, $user["uniqid"], $user['htmlemail']);
+        if ( FORWARD_ALTERNATIVE_CONTENT && $_GET['tab'] == 'Forward') {
+          if (SEND_ONE_TESTMAIL) {
+            $success = sendEmail($id, $address, $user["uniqid"], $user['htmlemail'], array(), array($address) );
+          } else {
+            $success = sendEmail($id, $address, $user["uniqid"], 1,  array(), array($address) ) && sendEmail($id, $address, $user["uniqid"], 0,  array(), array($address));
+          }
         } else {
-          $success = sendEmail($id, $address, $user["uniqid"], 1) && sendEmail($id, $address, $user["uniqid"], 0);
+          if (SEND_ONE_TESTMAIL) {
+            $success = sendEmail($id, $address, $user["uniqid"], $user['htmlemail']);
+          } else {
+            $success = sendEmail($id, $address, $user["uniqid"], 1) && sendEmail($id, $address, $user["uniqid"], 0);
+          }
         }
-;
         print $GLOBALS['I18N']->get("sentemailto").": $address ";
         if (!$success) {
           print $GLOBALS['I18N']->get('failed');
@@ -647,6 +710,19 @@ if ($send || $sendtest || $prepare || $save) {
 # load all message data
 $messagedata = loadMessageData($id);
 
+#0013076: different content when forwarding 'to a friend'
+if (FORWARD_ALTERNATIVE_CONTENT) {
+  foreach( array('forwardsubject', 'forwardmessage', 'forwardfooter') as $var) {
+  	if (isset($_REQUEST[$var])) {
+      ${$var} = stripslashes($_REQUEST[$var]);
+    } else {
+      ${$var} = stripslashes($messagedata[$var]);
+    }
+  }
+  if (!$forwardfooter)
+    $forwardfooter = getConfig("forwardfooter");
+}
+
 ##############################
 # Stacked attributes, processing and calculation
 ##############################
@@ -681,7 +757,8 @@ for ($i = 1; $i<=$num;$i++) {
       $attribute = '';
     }
     ## fix 6063
-    $crit_data["values"] = str_replace(" ", "",$crit_data["values"]);
+  #  $crit_data["values"] = str_replace(" ,", "",$crit_data["values"]);
+    $crit_data['values'] = cleanCommaList($crit_data["values"]);
 
     # hmm, rather get is some other way, this is a bit unnecessary
     $type = Sql_Fetch_Row_Query("select type from {$tables["attribute"]} where id = ".$crit_data["attribute"]);
@@ -712,7 +789,7 @@ for ($i = 1; $i<=$num;$i++) {
         }
         $where_clause .= $or_clause . ") ) ";
         $subqueries[$i]['query'] = sprintf('select userid from %s as table%d where attributeid = %d
-          and %s',$GLOBALS['tables']['user_attribute'],$tc,$crit_data['attribute'],$or_clause);
+          and ( %s )',$GLOBALS['tables']['user_attribute'],$tc,$crit_data['attribute'],$or_clause);
         break;
       case "checkbox":
         $value = $crit_data["values"][0];
@@ -737,7 +814,7 @@ for ($i = 1; $i<=$num;$i++) {
 
         $where_clause .= '( '.$valueselect . ') ) ';
         $subqueries[$i]['query'] = sprintf('select userid from %s as table%d where attributeid = %d
-          and %s',$GLOBALS['tables']['user_attribute'],$tc,$crit_data['attribute'],$valueselect);
+          and ( %s )',$GLOBALS['tables']['user_attribute'],$tc,$crit_data['attribute'],$valueselect);
 
         break;
       case "date":
@@ -785,7 +862,7 @@ for ($i = 1; $i<=$num;$i++) {
         } else {
           $where_clause .= ' in (';
         }
-        $where_clause .= $crit_data["values"] . ") )";
+        $where_clause .= cleanCommaList($crit_data["values"]) . ") )";
         $subqueries[$i]['query'] = sprintf('select userid from %s
         where attributeid = %d and
         value %s in (%s) ',$GLOBALS['tables']['user_attribute'],
@@ -880,6 +957,9 @@ if (!$done) {
   if ($_GET["id"]) {
     $tabs = new WebblerTabs();
     $tabs->addTab($GLOBALS['I18N']->get("Content"),"$baseurl&amp;tab=Content");
+    if (FORWARD_ALTERNATIVE_CONTENT) {
+      $tabs->addTab($GLOBALS['I18N']->get("Forward"),"$baseurl&amp;tab=Forward");
+    }
     $tabs->addTab($GLOBALS['I18N']->get("Format"),"$baseurl&amp;tab=Format");
     if (ALLOW_ATTACHMENTS) {
       $tabs->addTab($GLOBALS['I18N']->get("Attach"),"$baseurl&amp;tab=Attach");
@@ -944,22 +1024,52 @@ if (!$done) {
   }
 
   $formatting_content = '<table>';
-  $maincontent = '<table>';
+  
+  #0013076: different content when forwarding 'to a friend'
+  //  value="'.htmlentities($subject,ENT_QUOTES,'UTF-8').'" size=40></td></tr> --> previous code in line 1032
+  //  value="'.htmlentities($from,ENT_QUOTES,'UTF-8').'" size=40></td></tr> --> previous code in line 1038
+
+  $tmp = '<table>';
+  $maincontent = $tmp;
+  $forwardcontent = $tmp;
+
   $scheduling_content = '<table>';
+// custom code - start
+  $utf8_subject = $subject;
+  $utf8_from = $from;
+  if (strcasecmp($GLOBALS['strCharSet'], 'utf-8') <> 0 && function_exists('iconv')) {
+     $utf8_subject = iconv($GLOBALS['strCharSet'],'UTF-8',$utf8_subject);
+     $utf8_from = iconv($GLOBALS['strCharSet'],'UTF-8',$utf8_from);
+  }
+
   $maincontent .= '
   <tr><td>'.Help("subject").' '.$GLOBALS['I18N']->get("Subject").':</td>
     <td><input type=text name="msgsubject"
-    value="'.htmlentities($subject,ENT_QUOTES,'UTF-8').'" size=40></td></tr>
+    value="'.htmlentities($utf8_subject,ENT_QUOTES,'UTF-8').'" size=40></td></tr>
   <tr>
     <td colspan=2>
     </td></tr>
   <tr><td>'.Help("from").' '.$GLOBALS['I18N']->get("fromline").':</td>
     <td><input type=text name=from
-    value="'.htmlentities($from,ENT_QUOTES,'UTF-8').'" size=40></td></tr>
+   value="'.htmlentities($utf8_from,ENT_QUOTES,'UTF-8').'" size=40></td></tr>
   <tr><td colspan=2>
 
   </td></tr>';
 
+// custom code - end
+  #0013076: different content when forwarding 'to a friend'
+  $forwardcontent .= $GLOBALS['I18N']->get("When a user forwards to a friend," .
+  " the friend will receive this message instead of the one on the content tab.").
+  '<tr><td>'.Help("subject").' '.$GLOBALS['I18N']->get("Subject").':</td>
+    <td><input type=text name="forwardsubject"
+    value="'.htmlentities($forwardsubject,ENT_QUOTES,'UTF-8').'" size=40></td></tr>
+  <tr>
+    <td colspan=2>
+    </td></tr>
+  <td colspan=2>
+
+  </td></tr>';
+
   $scheduling_content .= '
   <tr><td>'.Help("embargo").' '.$GLOBALS['I18N']->get("embargoeduntil").':</td>
     <td>'.$embargo->showInput("embargo","",$_POST["embargo"]).'</td></tr>
@@ -1055,16 +1165,20 @@ if (!$done) {
     $rss_content .= '</td></tr>';
   }
 
-  $maincontent .= '<tr><td colspan=2>'.Help("message").' '.$GLOBALS['I18N']->get("message").'. </td></tr>
+  #0013076: different content when forwarding 'to a friend'
+  $tmp = '<tr><td colspan=2>'.Help("message").' '.$GLOBALS['I18N']->get("message").'. </td></tr>
 
   <tr><td colspan=2>';
+  $maincontent .= $tmp; 
+  $forwardcontent .= $tmp;
 
   if ($usefck) {
     $oFCKeditor = new FCKeditor('message') ;
     $oFCKeditor->BasePath = './FCKeditor/';
     //$oFCKeditor->ToolbarSet = 'Accessibility' ;
     $oFCKeditor->ToolbarSet = 'Default' ;
-    $oFCKeditor->Value = stripslashes($_POST["message"]);
+//    $oFCKeditor->Value = stripslashes($_POST["message"]);
+    $oFCKeditor->Value = $_POST["message"];
     $w = getConfig("fckeditor_width");
     $h = getConfig("fckeditor_height");
     if ($_SESSION["fckeditor_height"]) {
@@ -1111,16 +1225,20 @@ if (!$done) {
         ."   });\n"
         ."</script>\n"
         ."<textarea name='message' id='message' cols='65' rows='20'>{$_POST['message']}</textarea>";
-
+        
   } else {
-
-    $maincontent .= '<textarea name=message cols=65 rows=20>'.htmlspecialchars($_POST["message"]).'</textarea>';
-
+    $maincontent    .= '<textarea name=message cols=65 rows=20>'.htmlspecialchars($_POST["message"]).'</textarea>';
   }
 
-  $maincontent .= '
+  #0013076: different content when forwarding 'to a friend'
+  $forwardcontent .= '<textarea name=forwardmessage cols=65 rows=20>'.htmlspecialchars($forwardmessage).'</textarea>';
+
+  #0013076: different content when forwarding 'to a friend'
+  $tmp = '
   </td></tr>
   ';
+  $maincontent .= $tmp;
+  $forwardcontent .= $tmp;
 
   if (USE_MANUAL_TEXT_PART) {
   $maincontent .= '<tr><td colspan=2>
@@ -1131,12 +1249,18 @@ if (!$done) {
   </td></tr>';
   }
 
+  #0013076: different content when forwarding 'to a friend'
   $maincontent .= '<tr><td colspan=2>'.$GLOBALS['I18N']->get("messagefooter").'. <br/>
     '.$GLOBALS['I18N']->get("messagefooterexplanation").'<br/>'.
     $GLOBALS['I18N']->get("use [FORWARD] to add a personalised URL to forward the message to someone else.").
   '.</td></tr>
   <tr><td colspan=2><textarea name=footer cols=65 rows=5>'.$footer.'</textarea></td></tr>
   </table>';
+  $forwardcontent .= '<tr><td colspan=2>'.$GLOBALS['I18N']->get("forwardfooter").'. <br/>
+    '.$GLOBALS['I18N']->get("messageforwardfooterexplanation").'<br/>'.
+  '.</td></tr>
+  <tr><td colspan=2><textarea name=forwardfooter cols=65 rows=5>'.$forwardfooter.'</textarea></td></tr>
+  </table>';
 
   if (ALLOW_ATTACHMENTS) {
     // If we have a message id saved, we want to query the attachments that are associated with this
@@ -1521,6 +1645,7 @@ if (!$done) {
     case "Lists": $show_lists = 1;break;
     case "Review": print $review_content; break;
     case "Misc": print $notification_content; break;
+    case "Forward": print $forwardcontent; break;
     default:
       print $maincontent;
       break;
